@@ -2,15 +2,17 @@
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
+from typing import Union
+
 import click
-from click.core import Context, Option
+from click import Context, Option, Parameter
 
 from ._filename import sanitize_filename, validate_filename
 from ._filepath import sanitize_filepath, validate_filepath
 from .error import ValidationError
 
 
-def validate_filename_arg(ctx: Context, param: Option, value: str) -> str:
+def validate_filename_arg(ctx: Context, param: Union[Option, Parameter], value: str) -> str:
     if not value:
         return ""
 
@@ -22,7 +24,7 @@ def validate_filename_arg(ctx: Context, param: Option, value: str) -> str:
     return value
 
 
-def validate_filepath_arg(ctx: Context, param: Option, value: str) -> str:
+def validate_filepath_arg(ctx: Context, param: Union[Option, Parameter], value: str) -> str:
     if not value:
         return ""
 
@@ -34,14 +36,14 @@ def validate_filepath_arg(ctx: Context, param: Option, value: str) -> str:
     return value
 
 
-def sanitize_filename_arg(ctx: Context, param: Option, value: str) -> str:
+def sanitize_filename_arg(ctx: Context, param: Union[Option, Parameter], value: str) -> str:
     if not value:
         return ""
 
     return sanitize_filename(value)
 
 
-def sanitize_filepath_arg(ctx: Context, param: Option, value: str) -> str:
+def sanitize_filepath_arg(ctx: Context, param: Union[Option, Parameter], value: str) -> str:
     if not value:
         return ""
 
